--[[ Roster module to Handle the Raid Roster    ]]
--[[ tab widths set to 4 for optimal formatting ]]

local _, TriageTable = ...; 

local Triage = TriageTable.Triage
Triage.Dialog = Triage:NewModule("Dialog", "AceEvent-3.0", "AceBucket-3.0")
local Dialog = Triage.Dialog

local L = LibStub("AceLocale-3.0"):GetLocale("Triage");



function Dialog:Debug( str, ... )
	Triage:Debug("|c933f9fffDialog|r - "..str , ... )
end



function Dialog:OnInitialize() 
	self:Debug( "OnInitialize" )
end



function Dialog:OnEnable()
	self:Debug( "OnEnable" )

	if not self.frame then
		self:CreateDialog()
	end
end



function Dialog:OnLoad()
	self:Debug( "OnLoad" )
end



function Dialog:CreateDialog()
	self:Debug( "CreateDialog" )

	-- Localize the XML
	_G["TriageDialogAvailableLabel"]:SetText(L["Unassigned"])
	_G["TriageDialogAssignmentGroup1Label"]:SetText(L["Assignment 1"])
	_G["TriageDialogAssignmentGroup2Label"]:SetText(L["Assignment 2"])
	_G["TriageDialogAssignmentGroup3Label"]:SetText(L["Assignment 3"])
	_G["TriageDialogAssignmentGroup4Label"]:SetText(L["Assignment 4"])
	_G["TriageDialogAssignmentGroup5Label"]:SetText(L["Assignment 5"])
	_G["TriageDialogAssignmentGroup6Label"]:SetText(L["Assignment 6"])
	_G["TriageDialogAssignmentGroup7Label"]:SetText(L["Assignment 7"])
	_G["TriageDialogAssignmentGroup8Label"]:SetText(L["Assignment 8"])

	self.frame = TriageDialog
end


-- Deprecated, kept for now for reference.  TODO: delete
function Dialog:CreateMainDialog()
	self:Debug( "CreateMainDialog" )

	local font = media and media:Fetch("font", self.db.profile.font) or STANDARD_TEXT_FONT

	local frame = CreateFrame( "Frame", "TriageDialog", UIParent )

	frame:SetWidth( 480 )
	frame:SetHeight( 600 )

	frame:SetFrameStrata( "DIALOG")
	frame:SetToplevel( true )
	frame:EnableMouse( true )
	frame:SetClampedToScreen( true )

	frame:SetMovable( true )
	frame:SetPoint( "TOP", UIParent, "TOP", 0, -50 )

	frame:SetBackdrop{
		bgFile="Interface\\DialogFrame\\UI-DialogBox-Background" ,
		edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border",
		tile = true,
		insets = {left = 11, right = 12, top = 12, bottom = 11},
		tileSize = 32, edgeSize = 32,
	}

	frame.texture = frame:CreateTexture( nil, "BORDER" )
	frame.texture:SetPoint( "TOPLEFT", frame, "TOPLEFT", 4, -4 )
	frame.texture:SetPoint( "BOTTOMRIGHT", frame, "BOTTOMRIGHT", -4, 4 )
	frame.texture:SetBlendMode( "ADD" )
	frame.texture:SetGradientAlpha( "VERTICAL", .1, .1, .1, 0, .2, .2, .2, 0.5 )
	frame:EnableMouse( true )
	
	local titleRegion = frame:CreateTitleRegion()
	titleRegion:SetPoint( "TOP", frame, "TOP", 0, 22 )
	titleRegion:SetPoint( "LEFT", frame, "TOP", -50, 0 )
	titleRegion:SetPoint( "RIGHT", frame, "TOP", 50, 0 )
	titleRegion:SetPoint( "BOTTOM", frame, "TOP", 0, -16 )

	local header = frame:CreateTexture( nil, "ARTWORK" )
	header:SetTexture( "Interface\\DialogFrame\\UI-DialogBox-Header" )
	header:SetWidth( 256 )
	header:SetHeight( 64 )
	header:SetPoint( "TOP", 0, 12 )

	local title = frame:CreateFontString( "ARTWORK" )
	title:SetFontObject( "GameFontNormal" )
	title:SetPoint( "TOP", header, "TOP", 0, -14 )
	title:SetText( L["Triage"] )

	local closeButton = CreateFrame( "Button", "CloseDialogButton",
		frame, "UIPanelCloseButton")
	closeButton:SetPoint( "TOPRIGHT", 0, 0)
	closeButton:SetScript( "OnClick", function( self ) Dialog:HideDialog() end )

	frame:SetScript( "OnShow", function() PlaySound( "igMainMenuOption" ) end )
	frame:SetScript( "OnHide", function() PlaySound( "gsTitleOptionExit" ) end )

	frame:Hide()
	tinsert( UISpecialFrames,"TriageDialog" );
	return frame
end



function Dialog:CreateAvailable( parent )
	self:Debug( "CreateAvailable" )

	local frame = CreateFrame( "Frame", "TriageAvailable", parent )

	frame:SetWidth( 100 )
	frame:SetHeight( 261 )

	frame:SetPoint( "TOPLEFT", parent, "TOPLEFT", 14, -45 )

	frame:SetBackdrop{
		bgFile="Interface\\DialogFrame\\UI-DialogBox-Background" ,
--		edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border",
		tile = true,
		insets = {left = 1, right = 1, top = 1, bottom = 1},
		tileSize = 32, edgeSize = 32,
	}

	frame.texture = frame:CreateTexture( nil, "BORDER" )
	frame.texture:SetPoint( "TOPLEFT", frame, "TOPLEFT", 4, -4 )
	frame.texture:SetPoint( "BOTTOMRIGHT", frame, "BOTTOMRIGHT", -4, 4 )
	frame.texture:SetBlendMode( "DISABLE" )
--	frame.texture:SetGradientAlpha( "VERTICAL", .1, .1, .1, 0, .2, .2, .2, 0.5 )
	frame:EnableMouse( true )

	frame.slots = { }
	for index, slotname in ipairs( self.available ) do
		local slot = self:CreateAvailableSlot( frame, index, slotname )
		frame.slots[ index ] = slot
	end

	parent.availableFrame = frame
end




function Dialog:Dialog()
	self:Debug( "Dialog" )
end



function Dialog:ShowDialog()
	self:Debug( "ShowDialog" )
	if Triage.inCombat then
		self:Debug( "  in combat, refusing to display" );
		return
	end
	if self.frame then
		self.frame:Show()
	else 
		 TriageDialog:Show()
	end
	
end



function Dialog:HideDialog()
	self:Debug( "HideDialog" )
	if self.frame then
		self.frame:Hide()
	end
end



function Dialog:AvailableSlotOnLoad( slot )
	self:Debug( "AvailableSlotOnLoad" )
end
